/*
 * @Author: PoJun
 * @Date: 2022-02-28 10:18:24
 * @LastEditors: PoJun
 * @LastEditTime: 2024-04-10 15:38:12
 * @Message: Do not edit
 */
import axios from "axios";
import Vue from "vue";
import { encodeURL, mergeURL } from "./jointURL";
import Cookie from "js-cookie";
import { logoutSystem } from "@/utils/util";

const defaultConfig = {
    baseURL: process.env.NODE_ENV == "development" ? "/api" : process.env.VUE_APP_API_BASE_URL, //代理域名路径
    timeout: 15000,
    headers: {
        get: {
            "Content-Type": "application/x-www-form-urlencoded;charset=utf-8",
            type: "web",
        },
        post: {
            "Content-Type": "application/json;charset=utf-8",
            type: "web",
        },
    },
    withCredentials: true,
    validateStatus(status) {
        return status < 400;
    },
    transformResponse: [
        data => {
            if (typeof data === "string" && data.startsWith("{")) {
                data = JSON.parse(data);
            }
            return data;
        },
    ],
};
// request拦截器
axios.interceptors.request.use(
    req => {
        const token = Cookie.get("satoken");
        if (!req.noToken) {
            req.headers.satoken = token;
        }
        return req;
    },
    error => {
        return Promise.reject(error);
    }
);
// respone拦截器
axios.interceptors.response.use(
    response => {
        const status = response.status,
            config = response.config;
        if (status === 200) {
            if (config.notIntercept) {
                return response.data;
            }
            const { data, code, message } = response.data;

            if (code === 200 || code === 0) {
                if (config.showMsg) {
                    Vue.prototype.$message.success(message);
                }
                return data;
            } else if (code === 401 || code === 1) {
                Vue.prototype.$message.error({ content: message, key: "noLogin" });
                logoutSystem();
                return Promise.reject(new Error(message));
            } else {
                if (config.showMsg) {
                    Vue.prototype.$message.error(message);
                }
                return Promise.reject(new Error(message));
            }
        } else {
            Vue.prototype.$message.error(response.statusText);
            return Promise.reject(new Error(response.statusText));
        }
    },
    error => {
        return Promise.reject(error);
    }
);

// 封装 get 请求
export const $get = ({ url, reqConfig, params, pathAdd, headers }) => {
    reqConfig = reqConfig ? { ...defaultConfig, ...reqConfig } : { ...defaultConfig };
    if (headers) {
        reqConfig.headers.get = { ...reqConfig.headers.get, ...headers };
    }
    return axios.get(encodeURL(mergeURL(url, pathAdd), params), reqConfig, headers);
};

// 封装 post 请求
export const $post = ({ url, reqConfig, params, pathAdd, data, headers }) => {
    reqConfig = reqConfig ? { ...defaultConfig, ...reqConfig } : { ...defaultConfig };
    if (headers) {
        reqConfig.headers.post = { ...reqConfig.headers.post, ...headers };
    }
    return axios.post(encodeURL(mergeURL(url, pathAdd), params), data, reqConfig, headers);
};
