/*
 * @Author: PoJun
 * @Date: 2023-08-18 14:01:44
 * @LastEditors: PoJun
 * @LastEditTime: 2023-09-11 17:37:55
 * @Message: Nothing
 */
import Vue from "vue";
import Router from "vue-router";
import { formatRoutes } from "@/utils/routerUtil";
import store from "@/store";
//获取原型对象上的push函数
const originalPush = Router.prototype.push;
//修改原型对象中的push方法
Router.prototype.push = function push(location) {
    return originalPush.call(this, location).catch(err => err);
};

Vue.use(Router);

// 不需要登录拦截的路由配置
const loginIgnore = {
    names: ["404", "403", "500"], //根据路由名称匹配
    paths: ["/login"], //根据路由fullPath匹配
    /**
     * 判断路由是否包含在该配置中
     * @param route vue-router 的 route 对象
     * @returns {boolean}
     */
    includes(route) {
        return this.names.includes(route.name) || this.paths.includes(route.path);
    },
};

/**
 * 初始化路由实例
 * @param isAsync 是否异步路由模式
 * @returns {VueRouter}
 */
function initRouter(isAsync) {
    const options = isAsync ? require("./async/config.async").default : require("./config").default;
    formatRoutes(options.routes);
    return new Router(options);
}

// 这样是为了在js页面去import router对象.
const router = initRouter(store.state.setting.asyncRoutes);

export { loginIgnore, router };
