/*
 * @Author: PoJun
 * @Date: 2023-09-01 09:42:16
 * @LastEditors: PoJun
 * @LastEditTime: 2023-10-24 14:36:46
 * @Message: Nothing
 */
import enquireJs from "enquire.js";
import { removeAuthorization } from "@/utils/request";
import { router } from "@/router/index";

/**
 * 通过资源id获取图片的展示信息
 */
export function getImageUrl(id) {
    return id ? process.env.VUE_APP_API_BASE_URL + `/files/${id}/show_image` : "";
}

/**
 * 对象赋值, 且最终只保留源对象的键值
 */
export function mergeObjects(objA, objB) {
    if (!objA || !objB) {
        return {};
    }

    const keysA = Object.keys(objA);

    const mergedObj = keysA.reduce((acc, key) => {
        if (Object.prototype.hasOwnProperty.call(objB, key)) {
            acc[key] = objB[key];
        } else {
            acc[key] = objA[key];
        }
        return acc;
    }, {});

    return mergedObj;
}

/**
 * 退出系统、登录失效的退出动作处理
 */
export function logoutSystem() {
    localStorage.removeItem(process.env.VUE_APP_ROUTES_KEY);
    localStorage.removeItem(process.env.VUE_APP_USER_KEY);
    localStorage.removeItem(process.env.VUE_APP_ORG_KEY);
    removeAuthorization();
    router.replace({ path: "/login" });
}

/**
 * Remove an item from an array.
 */
export function remove(arr, item) {
    if (arr.length) {
        const index = arr.indexOf(item);
        if (index > -1) {
            return arr.splice(index, 1);
        }
    }
}

export function isRegExp(v) {
    return _toString.call(v) === "[object RegExp]";
}

export function enquireScreen(call) {
    const handler = {
        match: function () {
            call && call(true);
        },
        unmatch: function () {
            call && call(false);
        },
    };
    enquireJs.register("only screen and (max-width: 767.99px)", handler);
}

const _toString = Object.prototype.toString;
